@@ -13,8 +13,8 @@
 # limitations under the License.
 
 import copy
-from gz_test_deps.sdformat import Pbr, PbrWorkflow
-import gz_test_deps.sdformat as sdf
+from sdformat import Pbr, PbrWorkflow
+import sdformat as sdf
 import unittest
 
 
