@@ -18,6 +18,7 @@
 #include <gz/math/Pose3.hh>
 #include "sdf/Frame.hh"
 #include "sdf/Error.hh"
+#include "sdf/parser.hh"
 #include "sdf/Types.hh"
 #include "FrameSemantics.hh"
 #include "ScopedGraph.hh"
@@ -94,7 +95,7 @@ Errors Frame::Load(ElementPtr _sdf)
   // Read the frame's attached_to attribute
   if (_sdf->HasAttribute("attached_to"))
   {
-    auto pair = _sdf->Get<std::string>("attached_to", "");
+    auto pair = _sdf->Get<std::string>(errors, "attached_to", "");
     if (pair.second)
     {
       this->dataPtr->attachedTo = pair.first;
@@ -217,3 +218,35 @@ sdf::ElementPtr Frame::Element() const
 {
   return this->dataPtr->sdf;
 }
+
+/////////////////////////////////////////////////
+sdf::ElementPtr Frame::ToElement() const
+{
+  sdf::Errors errors;
+  auto result = this->ToElement(errors);
+  sdf::throwOrPrintErrors(errors);
+  return result;
+}
+
+/////////////////////////////////////////////////
+sdf::ElementPtr Frame::ToElement(sdf::Errors &_errors) const
+{
+  sdf::ElementPtr elem(new sdf::Element);
+  sdf::initFile("frame.sdf", elem);
+
+  elem->GetAttribute("name")->Set(this->dataPtr->name, _errors);
+
+  if (!this->dataPtr->attachedTo.empty())
+    elem->GetAttribute("attached_to")->Set(this->dataPtr->attachedTo, _errors);
+
+  // Set pose
+  sdf::ElementPtr poseElem = elem->GetElement("pose", _errors);
+  if (!this->dataPtr->poseRelativeTo.empty())
+  {
+    poseElem->GetAttribute("relative_to")->Set<std::string>(
+        this->dataPtr->poseRelativeTo, _errors);
+  }
+  poseElem->Set<gz::math::Pose3d>(_errors, this->RawPose());
+
+  return elem;
+}
