@@ -16,7 +16,9 @@
 */
 #include <algorithm>
 #include <array>
+#include <map>
 #include <memory>
+#include <optional>
 #include <string>
 #include <utility>
 #include <gz/math/Pose3.hh>
@@ -306,30 +308,6 @@ void Joint::SetChildName(const std::string &_name)
   this->dataPtr->childName = _name;
 }
 
-/////////////////////////////////////////////////
-const std::string &Joint::ParentLinkName() const
-{
-  return this->ParentName();
-}
-
-/////////////////////////////////////////////////
-void Joint::SetParentLinkName(const std::string &_name)
-{
-  this->SetParentName(_name);
-}
-
-/////////////////////////////////////////////////
-const std::string &Joint::ChildLinkName() const
-{
-  return this->ChildName();
-}
-
-/////////////////////////////////////////////////
-void Joint::SetChildLinkName(const std::string &_name)
-{
-  this->SetChildName(_name);
-}
-
 /////////////////////////////////////////////////
 const JointAxis *Joint::Axis(const unsigned int _index) const
 {
