@@ -237,12 +237,6 @@ bool ParserConfig::URDFPreserveFixedJoint() const
   return this->dataPtr->preserveFixedJoint;
 }
 
-/////////////////////////////////////////////////
-void ParserConfig::SetStoreResovledURIs(bool _resolveURI)
-{
-  this->SetStoreResolvedURIs(_resolveURI);
-}
-
 /////////////////////////////////////////////////
 void ParserConfig::SetStoreResolvedURIs(bool _resolveURI)
 {
