@@ -23,7 +23,16 @@
 #include <gz/math/Pose3.hh>
 #include <gz/math/Vector3.hh>
 
-#include "sdf/sdf.hh"
+#include "sdf/Collision.hh"
+#include "sdf/Frame.hh"
+#include "sdf/Joint.hh"
+#include "sdf/JointAxis.hh"
+#include "sdf/Link.hh"
+#include "sdf/Model.hh"
+#include "sdf/parser.hh"
+#include "sdf/Root.hh"
+#include "sdf/Visual.hh"
+#include "sdf/World.hh"
 
 #include "test_config.hh"
 
@@ -114,33 +123,42 @@ TEST(NestedModel, State)
   sdfStr << "<sdf version ='" << SDF_VERSION << "'>"
     << "<world name='default'>"
     << "<state world_name='default'>"
-    << "<model name='model_00'>"
+    << "<model_state name='model_00'>"
     << "  <pose>0 0 0.5 0 0 0</pose>"
-    << "  <link name='link_00'>"
+    << "  <link_state name='link_00'>"
     << "    <pose>0 0 0.5 0 0 0</pose>"
-    << "    <velocity>0.001 0 0 0 0 0</velocity>"
-    << "    <acceleration>0 0.006121 0 0.012288 0 0.001751</acceleration>"
-    << "    <wrench>0 0.006121 0 0 0 0</wrench>"
-    << "  </link>"
-    << "  <model name='model_01'>"
+    << "    <linear_velocity>0.001 0 0</linear_velocity>"
+    << "    <angular_velocity>-0.1 5.0 -0.1</angular_velocity>"
+    << "    <linear_acceleration>0 0.006121 0</linear_acceleration>"
+    << "    <angular_acceleration>0.012288 0 0.001751</angular_acceleration>"
+    << "    <force>0 0.006121 0</force>"
+    << "    <torque>0 0 0</torque>"
+    << "  </link_state>"
+    << "  <model_state name='model_01'>"
     << "    <pose>1 0 0.5 0 0 0</pose>"
-    << "    <link name='link_01'>"
+    << "    <link_state name='link_01'>"
     << "      <pose>1.25 0 0.5 0 0 0</pose>"
-    << "      <velocity>0 -0.001 0 0 0 0</velocity>"
-    << "      <acceleration>0 0.000674 0 -0.001268 0 0</acceleration>"
-    << "      <wrench>0 0.000674 0 0 0 0</wrench>"
-    << "    </link>"
-    << "    <model name='model_02'>"
+    << "      <linear_velocity>0 -0.001 0</linear_velocity>"
+    << "      <angular_velocity>0 0 0</angular_velocity>"
+    << "      <linear_acceleration>0 0.000674 0</linear_acceleration>"
+    << "      <angular_acceleration>-0.001268 0 0</angular_acceleration>"
+    << "      <force>0 0.000674 0</force>"
+    << "      <torque>0 0 0</torque>"
+    << "    </link_state>"
+    << "    <model_state name='model_02'>"
     << "      <pose>1 1 0.5 0 0 0</pose>"
-    << "      <link name='link_02'>"
+    << "      <link_state name='link_02'>"
     << "        <pose>1.25 1 0.5 0 0 0</pose>"
-    << "        <velocity>0 0 0.001 0 0 0</velocity>"
-    << "        <acceleration>0 0 0 0 0 0</acceleration>"
-    << "        <wrench>0 0 0 0 0 0</wrench>"
-    << "      </link>"
-    << "    </model>"
-    << "  </model>"
-    << "</model>"
+    << "        <linear_velocity>0 0 0.001</linear_velocity>"
+    << "        <angular_velocity>0 0 0</angular_velocity>"
+    << "        <linear_acceleration>0 0 0</linear_acceleration>"
+    << "        <angular_acceleration>0 0 0</angular_acceleration>"
+    << "        <force>0 0 0</force>"
+    << "        <torque>0 0 0</torque>"
+    << "      </link_state>"
+    << "    </model_state>"
+    << "  </model_state>"
+    << "</model_state>"
     << "</state>"
     << "</world>"
     << "</sdf>";
@@ -154,9 +172,9 @@ TEST(NestedModel, State)
   sdf::ElementPtr worldElem = sdfParsed->Root()->GetElement("world");
   EXPECT_TRUE(worldElem->HasElement("state"));
   sdf::ElementPtr stateElem = worldElem->GetElement("state");
-  EXPECT_TRUE(stateElem->HasElement("model"));
+  EXPECT_TRUE(stateElem->HasElement("model_state"));
 
-  sdf::ElementPtr modelStateElem = stateElem->GetElement("model");
+  sdf::ElementPtr modelStateElem = stateElem->GetElement("model_state");
 
   // model sdf
   EXPECT_TRUE(modelStateElem->HasAttribute("name"));
@@ -164,83 +182,126 @@ TEST(NestedModel, State)
   EXPECT_TRUE(modelStateElem->HasElement("pose"));
   EXPECT_EQ(modelStateElem->Get<gz::math::Pose3d>("pose"),
     gz::math::Pose3d(0, 0, 0.5, 0, 0, 0));
-  EXPECT_TRUE(!modelStateElem->HasElement("joint"));
+  EXPECT_FALSE(modelStateElem->HasElement("joint"));
+  EXPECT_FALSE(modelStateElem->HasElement("joint_state"));
 
   // link sdf
-  EXPECT_TRUE(modelStateElem->HasElement("link"));
-  sdf::ElementPtr linkStateElem = modelStateElem->GetElement("link");
+  EXPECT_TRUE(modelStateElem->HasElement("link_state"));
+  sdf::ElementPtr linkStateElem = modelStateElem->GetElement("link_state");
   EXPECT_TRUE(linkStateElem->HasAttribute("name"));
   EXPECT_EQ(linkStateElem->Get<std::string>("name"), "link_00");
   EXPECT_TRUE(linkStateElem->HasElement("pose"));
   EXPECT_EQ(linkStateElem->Get<gz::math::Pose3d>("pose"),
     gz::math::Pose3d(0, 0, 0.5, 0, 0, 0));
-  EXPECT_TRUE(linkStateElem->HasElement("velocity"));
-  EXPECT_EQ(linkStateElem->Get<gz::math::Pose3d>("velocity"),
-    gz::math::Pose3d(0.001, 0, 0, 0, 0, 0));
-  EXPECT_TRUE(linkStateElem->HasElement("acceleration"));
-  EXPECT_EQ(linkStateElem->Get<gz::math::Pose3d>("acceleration"),
-    gz::math::Pose3d(0, 0.006121, 0, 0.012288, 0, 0.001751));
-  EXPECT_TRUE(linkStateElem->HasElement("wrench"));
-  EXPECT_EQ(linkStateElem->Get<gz::math::Pose3d>("wrench"),
-    gz::math::Pose3d(0, 0.006121, 0, 0, 0, 0));
+  EXPECT_FALSE(linkStateElem->HasElement("velocity"));
+  EXPECT_TRUE(linkStateElem->HasElement("angular_velocity"));
+  EXPECT_TRUE(linkStateElem->HasElement("linear_velocity"));
+  EXPECT_EQ(linkStateElem->Get<gz::math::Vector3d>("linear_velocity"),
+    gz::math::Vector3d(0.001, 0, 0));
+  EXPECT_EQ(linkStateElem->Get<gz::math::Vector3d>("angular_velocity"),
+    gz::math::Vector3d(-0.1, 5.0, -0.1));
+  EXPECT_FALSE(linkStateElem->HasElement("acceleration"));
+  EXPECT_TRUE(linkStateElem->HasElement("angular_acceleration"));
+  EXPECT_TRUE(linkStateElem->HasElement("linear_acceleration"));
+  EXPECT_EQ(linkStateElem->Get<gz::math::Vector3d>("linear_acceleration"),
+    gz::math::Vector3d(0, 0.006121, 0));
+  EXPECT_EQ(linkStateElem->Get<gz::math::Vector3d>("angular_acceleration"),
+    gz::math::Vector3d(0.012288, 0, 0.001751));
+  EXPECT_FALSE(linkStateElem->HasElement("wrench"));
+  EXPECT_TRUE(linkStateElem->HasElement("torque"));
+  EXPECT_TRUE(linkStateElem->HasElement("force"));
+  EXPECT_EQ(linkStateElem->Get<gz::math::Vector3d>("force"),
+    gz::math::Vector3d(0, 0.006121, 0));
+  EXPECT_EQ(linkStateElem->Get<gz::math::Vector3d>("torque"),
+    gz::math::Vector3d(0, 0, 0));
 
   // nested model sdf
-  EXPECT_TRUE(modelStateElem->HasElement("model"));
+  EXPECT_TRUE(modelStateElem->HasElement("model_state"));
   sdf::ElementPtr nestedModelStateElem =
-    modelStateElem->GetElement("model");
+    modelStateElem->GetElement("model_state");
   EXPECT_TRUE(nestedModelStateElem->HasAttribute("name"));
   EXPECT_EQ(nestedModelStateElem->Get<std::string>("name"), "model_01");
   EXPECT_TRUE(nestedModelStateElem->HasElement("pose"));
   EXPECT_EQ(nestedModelStateElem->Get<gz::math::Pose3d>("pose"),
     gz::math::Pose3d(1, 0, 0.5, 0, 0, 0));
-  EXPECT_TRUE(!nestedModelStateElem->HasElement("joint"));
+  EXPECT_FALSE(nestedModelStateElem->HasElement("joint"));
+  EXPECT_FALSE(nestedModelStateElem->HasElement("joint_state"));
 
   // nested model's link sdf
-  EXPECT_TRUE(nestedModelStateElem->HasElement("link"));
+  EXPECT_TRUE(nestedModelStateElem->HasElement("link_state"));
   sdf::ElementPtr nestedLinkStateElem =
-    nestedModelStateElem->GetElement("link");
+    nestedModelStateElem->GetElement("link_state");
   EXPECT_TRUE(nestedLinkStateElem->HasAttribute("name"));
   EXPECT_EQ(nestedLinkStateElem->Get<std::string>("name"), "link_01");
   EXPECT_TRUE(nestedLinkStateElem->HasElement("pose"));
   EXPECT_EQ(nestedLinkStateElem->Get<gz::math::Pose3d>("pose"),
     gz::math::Pose3d(1.25, 0, 0.5, 0, 0, 0));
-  EXPECT_TRUE(nestedLinkStateElem->HasElement("velocity"));
-  EXPECT_EQ(nestedLinkStateElem->Get<gz::math::Pose3d>("velocity"),
-    gz::math::Pose3d(0, -0.001, 0, 0, 0, 0));
-  EXPECT_TRUE(nestedLinkStateElem->HasElement("acceleration"));
-  EXPECT_EQ(nestedLinkStateElem->Get<gz::math::Pose3d>("acceleration"),
-    gz::math::Pose3d(0, 0.000674, 0, -0.001268, 0, 0));
-  EXPECT_TRUE(nestedLinkStateElem->HasElement("wrench"));
-  EXPECT_EQ(nestedLinkStateElem->Get<gz::math::Pose3d>("wrench"),
-    gz::math::Pose3d(0, 0.000674, 0, 0, 0, 0));
+  EXPECT_FALSE(nestedLinkStateElem->HasElement("velocity"));
+  EXPECT_TRUE(nestedLinkStateElem->HasElement("angular_velocity"));
+  EXPECT_TRUE(nestedLinkStateElem->HasElement("linear_velocity"));
+  EXPECT_EQ(nestedLinkStateElem->Get<gz::math::Vector3d>("linear_velocity"),
+    gz::math::Vector3d(0, -0.001, 0));
+  EXPECT_EQ(nestedLinkStateElem->Get<gz::math::Vector3d>("angular_velocity"),
+    gz::math::Vector3d(0, 0, 0));
+  EXPECT_FALSE(nestedLinkStateElem->HasElement("acceleration"));
+  EXPECT_TRUE(nestedLinkStateElem->HasElement("angular_acceleration"));
+  EXPECT_TRUE(nestedLinkStateElem->HasElement("linear_acceleration"));
+  EXPECT_EQ(
+    nestedLinkStateElem->Get<gz::math::Vector3d>("linear_acceleration"),
+    gz::math::Vector3d(0, 0.000674, 0));
+  EXPECT_EQ(
+    nestedLinkStateElem->Get<gz::math::Vector3d>("angular_acceleration"),
+    gz::math::Vector3d(-0.001268, 0, 0));
+  EXPECT_FALSE(nestedLinkStateElem->HasElement("wrench"));
+  EXPECT_TRUE(nestedLinkStateElem->HasElement("torque"));
+  EXPECT_TRUE(nestedLinkStateElem->HasElement("force"));
+  EXPECT_EQ(nestedLinkStateElem->Get<gz::math::Vector3d>("force"),
+    gz::math::Vector3d(0, 0.000674, 0));
+  EXPECT_EQ(nestedLinkStateElem->Get<gz::math::Vector3d>("torque"),
+    gz::math::Vector3d(0, 0, 0));
 
   // double nested model sdf
-  EXPECT_TRUE(nestedModelStateElem->HasElement("model"));
-  nestedModelStateElem = nestedModelStateElem->GetElement("model");
+  EXPECT_TRUE(nestedModelStateElem->HasElement("model_state"));
+  nestedModelStateElem = nestedModelStateElem->GetElement("model_state");
   EXPECT_TRUE(nestedModelStateElem->HasAttribute("name"));
   EXPECT_EQ(nestedModelStateElem->Get<std::string>("name"), "model_02");
   EXPECT_TRUE(nestedModelStateElem->HasElement("pose"));
   EXPECT_EQ(nestedModelStateElem->Get<gz::math::Pose3d>("pose"),
     gz::math::Pose3d(1, 1, 0.5, 0, 0, 0));
-  EXPECT_TRUE(!nestedModelStateElem->HasElement("joint"));
+  EXPECT_FALSE(nestedModelStateElem->HasElement("joint"));
+  EXPECT_FALSE(nestedModelStateElem->HasElement("joint_state"));
 
   // double nested model's link sdf
-  EXPECT_TRUE(nestedModelStateElem->HasElement("link"));
-  nestedLinkStateElem = nestedModelStateElem->GetElement("link");
+  EXPECT_TRUE(nestedModelStateElem->HasElement("link_state"));
+  nestedLinkStateElem = nestedModelStateElem->GetElement("link_state");
   EXPECT_TRUE(nestedLinkStateElem->HasAttribute("name"));
   EXPECT_EQ(nestedLinkStateElem->Get<std::string>("name"), "link_02");
   EXPECT_TRUE(nestedLinkStateElem->HasElement("pose"));
   EXPECT_EQ(nestedLinkStateElem->Get<gz::math::Pose3d>("pose"),
     gz::math::Pose3d(1.25, 1, 0.5, 0, 0, 0));
-  EXPECT_TRUE(nestedLinkStateElem->HasElement("velocity"));
-  EXPECT_EQ(nestedLinkStateElem->Get<gz::math::Pose3d>("velocity"),
-    gz::math::Pose3d(0, 0, 0.001, 0, 0, 0));
-  EXPECT_TRUE(nestedLinkStateElem->HasElement("acceleration"));
-  EXPECT_EQ(nestedLinkStateElem->Get<gz::math::Pose3d>("acceleration"),
-    gz::math::Pose3d(0, 0, 0, 0, 0, 0));
-  EXPECT_TRUE(nestedLinkStateElem->HasElement("wrench"));
-  EXPECT_EQ(nestedLinkStateElem->Get<gz::math::Pose3d>("wrench"),
-    gz::math::Pose3d(0, 0, 0, 0, 0, 0));
+  EXPECT_FALSE(nestedLinkStateElem->HasElement("velocity"));
+  EXPECT_TRUE(nestedLinkStateElem->HasElement("angular_velocity"));
+  EXPECT_TRUE(nestedLinkStateElem->HasElement("linear_velocity"));
+  EXPECT_EQ(nestedLinkStateElem->Get<gz::math::Vector3d>("linear_velocity"),
+    gz::math::Vector3d(0, 0, 0.001));
+  EXPECT_EQ(nestedLinkStateElem->Get<gz::math::Vector3d>("angular_velocity"),
+    gz::math::Vector3d(0, 0, 0));
+  EXPECT_FALSE(nestedLinkStateElem->HasElement("acceleration"));
+  EXPECT_TRUE(nestedLinkStateElem->HasElement("angular_acceleration"));
+  EXPECT_TRUE(nestedLinkStateElem->HasElement("linear_acceleration"));
+  EXPECT_EQ(
+    nestedLinkStateElem->Get<gz::math::Vector3d>("linear_acceleration"),
+    gz::math::Vector3d(0, 0, 0));
+  EXPECT_EQ(
+    nestedLinkStateElem->Get<gz::math::Vector3d>("angular_acceleration"),
+    gz::math::Vector3d(0, 0, 0));
+  EXPECT_FALSE(nestedLinkStateElem->HasElement("wrench"));
+  EXPECT_TRUE(nestedLinkStateElem->HasElement("torque"));
+  EXPECT_TRUE(nestedLinkStateElem->HasElement("force"));
+  EXPECT_EQ(nestedLinkStateElem->Get<gz::math::Vector3d>("force"),
+    gz::math::Vector3d(0, 0, 0));
+  EXPECT_EQ(nestedLinkStateElem->Get<gz::math::Vector3d>("torque"),
+    gz::math::Vector3d(0, 0, 0));
 }
 
 ////////////////////////////////////////
@@ -413,7 +474,7 @@ TEST(NestedModel, NestedInclude)
 }
 
 //////////////////////////////////////////////////
-// Test parsing models with child models containg frames nested via <include>
+// Test parsing models with child models contain frames nested via <include>
 TEST(NestedModel, NestedModelWithFrames)
 {
   const std::string name = "test_model_with_frames";
@@ -734,7 +795,7 @@ TEST(NestedModel, PartiallyFlattened)
 
 //////////////////////////////////////////////////
 // Test parsing models that have two levels of nesting with child models
-// containg frames nested via <include>.
+// contain frames nested via <include>.
 // Compare parsed SDF with expected string
 TEST(NestedModel, TwoLevelNestedModelWithFramesDirectComparison)
 {
