@@ -18,7 +18,10 @@
 #include <string>
 #include <gtest/gtest.h>
 
-#include "sdf/sdf.hh"
+#include "sdf/Frame.hh"
+#include "sdf/Joint.hh"
+#include "sdf/Link.hh"
+#include "sdf/Model.hh"
 #include "sdf/parser.hh"
 #include "sdf/ParserConfig.hh"
 #include "test_config.hh"
